<?php
/**
 * Developer : MahdiY
 * Web Site  : MahdiY.IR
 * E-Mail    : M@hdiY.IR
 */

class PWS_Settings_SMS extends PWS_Settings {

	protected static $_instance = null;

	public static function instance() {

		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}

		return self::$_instance;
	}

	public function get_sections(): array {
		return [
			[
				'id'    => 'pws_sms_config',
				'title' => 'پیکربندی',
			],
			[
				'id'    => 'pws_sms_order',
				'title' => 'وضعیت سفارشات',
			],
			[
				'id'    => 'pws_sms_event',
				'title' => 'رویدادهای خاص',
			],
		];
	}

	public function get_fields(): array {

		$order_statuses = wc_get_order_statuses();

		$pws_sms_order = [
			[
				'name' => 'help',
				'desc' => '
 نکته :<ul>
								<li>برای ارسال نکردن پیامک در وضعیت خاص، روبروی آن را خالی بگذارید.</li>
								</ul>',
				'type' => 'html',
			],
			[
				'name' => 'shortcode',
				'desc' => '
می توانید از متغیرهای زیر استفاده کنید:<ul>
								<li><strong>{order}</strong> شماره سفارش</li>
								<li><strong>{first_name}</strong> نام مشتری</li>
								<li><strong>{last_name}</strong> نام خانوادگی مشتری</li>
								<li><strong>{barcode}</strong> بارکد پستی</li>
								<li><strong>{total}</strong> مبلغ کل سفارش</li>
								</ul>',
				'type' => 'html',
			],
		];

		$suggest_text = [
			'wc-processing'   => [
				'desc'    => 'مشتری گرامی، سفارش {order} ثبت و در حال پردازش است.',
			],
			'wc-pws-courier'  => [
				'desc'    => 'مشتری گرامی، سفارش {order} تحویل پیک شد.',
			],
			'wc-pws-packaged' => [
				'desc'    => 'مشتری گرامی، سفارش {order} بسته بندی و آماده ارسال شد.',
			],
			'wc-refunded'     => [
				'desc'    => 'مشتری گرامی، سفارش {order} مسترد شد.',
			],
			'wc-cancelled'    => [
				'desc'    => 'مشتری گرامی، سفارش {order} لغو شد.',
			],
			'wc-pws-in-stock' => [
				'desc'    => 'مشتری گرامی، سفارش {order} در حال آماده سازی در انبار می باشد.',
			],
		];

		foreach ( $order_statuses as $key => $order_status ) {
			$pws_sms_order[] = [
				'name'              => $key,
				'label'             => $order_status,
				'desc'              => isset( $suggest_text[ $key ] ) ? 'متن پیشنهادی:<br>' . get_bloginfo( 'name' ) . '<br>' . $suggest_text[ $key ]['desc'] : '',
				'type'              => 'text',
				'default'           => isset( $suggest_text[ $key ] ) ? $suggest_text[ $key ]['default'] : '',
				'sanitize_callback' => 'sanitize_text_field',
				'field_class'       => 'ltr',
			];
		}

		return [
			'pws_sms_config' => [
				[
					'name' => 'html',
					'desc' => '<b>آسانک:</b> پنل پیامک حرفه ای و پر سرعت را از <a href="https://asanak.com/" target="_blank">آسانک</a> تهیه کنید.',
					'type' => 'html',
				],
				[
					'name'  => 'enable',
					'label' => 'فعالسازی ارسال پیامک',
					'desc'  => 'پیامک در وضعیت های تنظیم شده برای مشتری ارسال می شود.',
					'type'  => 'checkbox',
				],
//				[
//					'name'  => 'credit',
//					'label' => 'نمایش اعتبار پیامک',
//					'desc'  => 'اعتبار پنل پیامک در منو بالا مدیریت نمایش داده می شود.',
//					'type'  => 'checkbox'
//				],
				[
					'name'              => 'username',
					'label'             => 'نام کاربری',
					'desc'              => 'نام کاربری پنل پیامک <a href="https://asanak.com/" target="_blank">آسانک</a>',
					'type'              => 'text',
					'default'           => '',
					'sanitize_callback' => 'sanitize_text_field',
				],
				[
					'name'              => 'password',
					'label'             => 'کلمه عبور',
					'desc'              => '',
					'type'              => 'password',
					'default'           => '',
					'sanitize_callback' => 'sanitize_text_field',
				],
				[
					'name'              => 'source',
					'label'             => 'شماره مبدا',
					'desc'              => '',
					'type'              => 'text',
					'default'           => '',
					'sanitize_callback' => 'sanitize_text_field',
				],
			],
			'pws_sms_order'  => $pws_sms_order,
			'pws_sms_event'  => [
				[
					'name'              => 'barcode',
					'label'             => 'ثبت بارکد پستی سفارش',
					'desc'              => 'متن پیشنهادی:<br>' . get_bloginfo( 'name' ) . '<br>مشتری گرامی، سفارش {order} به اداره پست تحویل داده شد.
<br>شما می توانید کد مرسوله {barcode} را از طریق لینک https://radgir.net رهگیری نمایید.',
					'type'              => 'text',
					'sanitize_callback' => 'sanitize_text_field',
					'field_class'       => 'ltr',
				],
			],
		];
	}

	public static function output() {

		$instance = self::instance();

		echo '<div class="wrap">';

		$instance->show_navigation();
		$instance->show_forms();

		echo '</div>';
	}
}
